# -*- coding: UTF-8 -*-
__author__ = "helios"
__doc__ = "__init__"
"""
  * @File    :   __init__.py
  * @Time    :   2023/04/26 17:17:32
  * @Author  :   helios
  * @Version :   1.0
  * @Contact :   yuyang.0515@qq.com
  * @License :   (C)Copyright 2019-2023, Ship of Ocean
  * @Desc    :   None
"""

__version__ = "0.0.1"
